@@ -7,6 +7,8 @@ use warnings;
 use LWP::UserAgent;
 use JSON;
 use URI::Encode qw(uri_encode);
+use File::Basename;
+use File::Path qw(make_path);
 
 $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = 0;
 use IO::Socket::SSL;
@@ -16,7 +18,7 @@ IO::Socket::SSL::set_ctx_defaults(
      verify_mode => 0,
 );
 
-our $VERSION = '1.14.1';
+our $VERSION = '1.24.0';
 
 =head1 NAME
 
@@ -151,9 +153,9 @@ sub simple {
 	my $url	= $self->make_url(action => 'simple', parameters => { %args });
 	my $res = $self->{_ua}->get($url);
 
-# 	$self->info($res->message);
-# 	$self->info($res->request->as_string);
-# 	$self->info($res->as_string);
+	# $self->info($res->message);
+	# $self->info($res->request->as_string);
+	# $self->info($res->as_string);
 	
 	return ($res->code, $res->decoded_content);
 }
@@ -187,6 +189,11 @@ Required. Local file name to write to.
 sub simple_file {
 	my ($self, %args) 	= @_;
 	my $file		= $args{file}	|| $self->error("Missing file in simple_file");
+	
+	if (-d $file) {
+		$self->error("You must specify a file path, not a folder, to save the screenshot");
+		return (400, '');
+	}
 
 	my $url	= $self->make_url(action => 'simple', parameters => { %args });
 	my $res = $self->{_ua}->get($url);
@@ -239,7 +246,7 @@ Required. Instance ID
 
 sub instance_info  {
 	my ($self, %args) 	= @_;
-	my $id				= $args{id}	|| $self->error("Missing id in instance_info");
+	my $id							= $args{id}	|| $self->error("Missing id in instance_info");
 
 	return $self->return_reply(action => 'instance/info', parameters => { id => $id });
 }
@@ -313,12 +320,12 @@ Optional. Screenshot size.
 
 sub screenshot_create {
 	my ($self, %args) 	= @_;
-# 	my $url				= $args{url}			|| $self->error("Missing url in screenshot_create");
-# 	my $instance_id		= $args{instance_id};
-# 	my $screen			= $args{screen};
-# 	my $size			= $args{size}			|| "screen";
-# 	my $cache			= $args{cache};
-# 	my $priority		= $args{priority};
+	# my $url				= $args{url}			|| $self->error("Missing url in screenshot_create");
+	# my $instance_id		= $args{instance_id};
+	# my $screen			= $args{screen};
+	# my $size			= $args{size}			|| "screen";
+	# my $cache			= $args{cache};
+	# my $priority		= $args{priority};
 
 	$self->error("Missing url in screenshot_create") 	if (! defined($args{url}));
 # 	$args{size} = "screen" 					if (! defined($args{size}));
@@ -396,7 +403,7 @@ Required. URL string to look for.
 
 sub screenshot_search {
 	my ($self, %args) 	= @_;
-	my $url			= $args{url}	|| $self->error("Missing id in screenshot_search");
+	my $url			= $args{url}	|| $self->error("Missing url in screenshot_search");
 
 	return $self->return_reply(action => 'screenshot/search', parameters => { %args });
 }
@@ -529,6 +536,11 @@ sub screenshot_thumbnail_file {
 
 	my $content = $self->screenshot_thumbnail(%args);
 
+	my $dir = dirname($file);
+	if (! -d $dir) {
+		make_path($dir)
+	}
+
 	if ($content ne '') {
 		open TARGET, "> $file" or $self->error("Cannot open $file for writing: $!");
 		binmode TARGET;
@@ -685,6 +697,7 @@ sub batch_create {
 	my $file		= $args{file}		|| $self->error("Missing file in batch_create");
 	my $instance_id		= $args{instance_id}	|| $self->error("Missing instance_id} in batch_create");
 
+	delete $args{file};
 	return $self->return_post_reply(action => 'batch/create', parameters => { %args }, file => $file);
 }
 
@@ -776,6 +789,7 @@ sub return_post_string {
 			  ]
 			);
 		};
+		$self->error($res->request->as_string) if ($@);
 		$self->error($@) if ($@);
 		$try++;
 	}
@@ -783,6 +797,8 @@ sub return_post_string {
 
 	if (! $res->is_success) {
 		$self->error("Server sent back an error: " . $res->code);
+		$self->info($res->request->as_string);
+		$self->info($res->as_string);
 	}
   
 	return $res->decoded_content;
@@ -885,6 +901,14 @@ sub generic_error {
 
 =over 4
 
+=item 1.24.0
+
+C<screenshot_thumbnail_file creates> the directory structure as needed.
+
+=item 1.16.0
+
+Check if the file is not a folder in simple_file
+
 =item 1.14.1
 
 Remove deprecated API calls.
